@@ -20,10 +20,10 @@ Training script for CIFAR10 models.
 
 import numpy as np
 
-from tensorflow.keras.datasets import cifar10
-from tensorflow.keras.callbacks import LearningRateScheduler, EarlyStopping
-from tensorflow.keras.utils import to_categorical
-from tensorflow.keras.preprocessing.image import ImageDataGenerator
+from keras.datasets import cifar10
+from keras.callbacks import LearningRateScheduler, EarlyStopping
+from keras.utils.np_utils import to_categorical
+from keras.preprocessing.image import ImageDataGenerator
 
 from cnn2snn import load_quantized_model, convert
 
@@ -55,7 +55,7 @@ def train_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
     """ Trains the model.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         x_test (numpy.ndarray): test data
@@ -102,7 +102,7 @@ def tune_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
     Similar to train but with a lower learning rate.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         x_test (numpy.ndarray): test data
