@@ -28,6 +28,7 @@ from .cifar10.model_ds_cnn import ds_cnn_cifar10
 from .cifar10.model_vgg import vgg_cifar10
 from .utk_face.model_vgg import vgg_utk_face
 from .kws.model_ds_cnn import ds_cnn_kws
+from .modelnet40.model_pointnet_plus import pointnet_plus_modelnet40
 from .imagenet.model_mobilenet import mobilenet_imagenet
 from .imagenet.model_vgg import vgg_imagenet
 from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
@@ -35,6 +36,7 @@ from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny_handy import convtiny_dvs_handy
 from .dvs.model_convtiny_gesture import convtiny_dvs_gesture
 from .cwru.model_convtiny import convtiny_cwru
+from .mnist.model_gxnor import gxnor_mnist
 
 
 def main():
@@ -107,7 +109,7 @@ def main():
                             help="The number of classes")
     mbe_parser = csp.add_parser("mobilenet_imagenet_edge",
                                 help="A MobileNet V1 model modified for akida \
-                               edge learning")
+                                edge learning")
     mbe_parser.add_argument("-bm",
                             "--base_model",
                             type=str,
@@ -119,6 +121,19 @@ def main():
                             type=int,
                             default=1000,
                             help="The number of edge learning classes")
+    pnet_parser = csp.add_parser("pointnet_plus_modelnet40",
+                                 help="A PointNet++ model for Akida")
+    pnet_parser.add_argument("-c",
+                             "--classes",
+                             type=int,
+                             default=40,
+                             help="The number of classes")
+    pnet_parser.add_argument("-alpha",
+                             "--alpha",
+                             type=float,
+                             default=1.0,
+                             help="Network filters multiplier (typically 0.5 , \
+                             [1.0]")
     yl_parser = csp.add_parser("yolo_base", help="A YOLOv2 model for detection")
     yl_parser.add_argument("-c",
                            "--classes",
@@ -142,10 +157,10 @@ def main():
                            help="The base MobileNet weights to use for \
                             transfer learning.")
     csp.add_parser("convtiny_cwru", help="A Convtiny CWRU model for akida")
+    csp.add_parser("gxnor_mnist", help="A GXNOR MNIST model for akida")
     args = parser.parse_args()
     if args.action == "create":
-        model_path = args.save_model
-        # Check extension
+        # Instantiate the wished model
         if args.model == "ds_cnn_cifar10":
             model = ds_cnn_cifar10()
         elif args.model == "vgg_cifar10":
@@ -158,20 +173,19 @@ def main():
             model = convtiny_dvs_gesture(classes=args.classes)
         elif args.model == "ds_cnn_kws":
             model = ds_cnn_kws()
+        elif args.model == "pointnet_plus_modelnet40":
+            model = pointnet_plus_modelnet40(alpha=args.alpha,
+                                             classes=args.classes)
         elif args.model == "mobilenet_imagenet":
             input_shape = (args.image_size, args.image_size, 3)
             model = mobilenet_imagenet(input_shape,
                                        alpha=args.alpha,
                                        classes=args.classes)
-            if model_path is None:
-                model_path = f"{model.name}.h5"
         elif args.model == "vgg_imagenet":
             model = vgg_imagenet(classes=args.classes)
         elif args.model == "mobilenet_imagenet_edge":
             model = mobilenet_edge_imagenet(base_model=args.base_model,
                                             classes=args.classes)
-            if model_path is None:
-                model_path = f"{model.name}.h5"
         elif args.model == "yolo_base":
             model = yolo_base(classes=args.classes,
                               nb_box=args.number_anchors,
@@ -180,13 +194,17 @@ def main():
                 model.load_weights(args.base_weights, by_name=True)
         elif args.model == "convtiny_cwru":
             model = convtiny_cwru()
+        elif args.model == "gxnor_mnist":
+            model = gxnor_mnist()
         # No need for default behaviour as the command-line parser only accepts
         # valid model types
+        model_path = args.save_model
         if model_path is None:
-            model_path = f"{args.model}.h5"
-        else:
-            # If needed, add the extension
-            if not model_path.endswith(".h5"):
-                model_path = f"{model_path}.h5"
+            model_path = \
+                f"{model.name}.h5" if args.model in ("mobilenet_imagenet", "mobilenet_imagenet_edge") else f"{args.model}.h5"
+
+        # If needed, add the extension
+        if not model_path.endswith(".h5"):
+            model_path = f"{model_path}.h5"
         model.save(model_path, include_optimizer=False)
         print(f"Model saved as {model_path}")
