@@ -31,7 +31,7 @@ import cv2
 import numpy as np
 
 from imgaug import augmenters as iaa
-from tensorflow.keras.utils import Sequence
+from keras.utils.data_utils import Sequence
 
 from .processing import BoundingBox
 
