@@ -23,7 +23,6 @@
 # ******************************************************************************
 """
 This module provides a method to generate YOLO anchors from dataset annotations.
-
 """
 
 import random
@@ -52,12 +51,12 @@ def _iou(ann, centroids):
 
 def _avg_iou(anns, centroids):
     n, _ = anns.shape
-    sum = 0.
+    s = 0.
 
     for i in range(anns.shape[0]):
-        sum += max(_iou(anns[i], centroids))
+        s += max(_iou(anns[i], centroids))
 
-    return sum / n
+    return s / n
 
 
 def _run_kmeans(ann_dims, anchor_num):
