@@ -22,8 +22,8 @@ import pickle
 
 import numpy as np
 
-from tensorflow.keras import Model
-from tensorflow.keras.utils import get_file
+from keras import Model
+from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
@@ -72,7 +72,7 @@ def yolo_base(input_shape=(224, 224, 3),
             convention, the scale factor is a number used as a divider.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     # Overrides input weight quantization if None
@@ -160,7 +160,7 @@ def yolo_widerface_pretrained():
     dataset and the anchors that are needed to interpet the model output.
 
     Returns:
-        tf.keras.Model, list: a Keras Model instance and a list of anchors.
+        keras.Model, list: a Keras Model instance and a list of anchors.
 
     """
     anchors_name = 'widerface_anchors.pkl'
@@ -190,7 +190,7 @@ def yolo_voc_pretrained():
     are needed to interpet the model output.
 
     Returns:
-        tf.keras.Model, list: a Keras Model instance and a list of anchors.
+        keras.Model, list: a Keras Model instance and a list of anchors.
 
     """
     anchors_name = 'voc_anchors.pkl'
