@@ -18,9 +18,9 @@
 Convtiny model definition for DVS gesture classification.
 """
 
-from tensorflow.keras.utils import get_file
-from tensorflow.keras import Model
-from tensorflow.keras.layers import Input, Reshape, Dropout, Activation
+from keras.utils.data_utils import get_file
+from keras import Model
+from keras.layers import Input, Reshape, Dropout, Activation
 
 from cnn2snn import load_quantized_model, quantize
 
@@ -57,7 +57,7 @@ def convtiny_dvs_gesture(input_shape=(64, 64, 6),
             * '1' through '8' implements n-bit weights where n is from 1-8 bits.
 
     Returns:
-        tf.keras.Model: a Keras convolutional model for DVS Gesture.
+        keras.Model: a Keras convolutional model for DVS Gesture.
     """
 
     img_input = Input(input_shape)
@@ -146,7 +146,7 @@ def convtiny_gesture_pretrained():
     trained on IBM DVS Gesture dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'convtiny_dvs_gesture_iq2_wq2_aq4.h5'
