@@ -20,9 +20,9 @@ applications. It is based on MobileNetBC with top layers replaced by a quantized
 spike extractor and a classification layer.
 """
 
-from tensorflow.keras import Model
-from tensorflow.keras.utils import get_file
-from tensorflow.keras.layers import Reshape, Activation
+from keras import Model
+from keras.utils.data_utils import get_file
+from keras.layers import Reshape, Activation
 
 from cnn2snn import load_quantized_model, quantize_layer
 
@@ -35,11 +35,11 @@ def mobilenet_edge_imagenet(base_model, classes):
     """Instantiates a MobileNet-edge architecture.
 
     Args:
-        base_model (str/tf.keras.Model): a mobilenet_imagenet quantized model.
+        base_model (str/keras.Model): a mobilenet_imagenet quantized model.
         classes (int) : the number of classes for the edge classifier.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
     """
     if isinstance(base_model, str):
         base_model = load_quantized_model(base_model)
@@ -98,7 +98,7 @@ def mobilenet_edge_imagenet_pretrained():
     trained on ImageNet dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'mobilenet_imagenet_224_alpha_50_edge_iq8_wq4_aq4.h5'
@@ -116,7 +116,7 @@ def mobilenet_faceidentification_edge_pretrained():
     on CASIA Webface dataset and that performs face identification.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'mobilenet_faceidentification_edge_iq8_wq4_aq4.h5'
