@@ -18,10 +18,9 @@
 VGG model definition for ImageNet classification.
 """
 
-from tensorflow.keras import Model, regularizers
-from tensorflow.keras.layers import Input, Activation, Dropout, Flatten
-from tensorflow.keras.layers.experimental.preprocessing import Rescaling
-from tensorflow.keras.utils import get_file
+from keras import Model, regularizers
+from keras.layers import (Input, Activation, Dropout, Flatten, Rescaling)
+from keras.utils.data_utils import get_file
 
 from cnn2snn import quantize, load_quantized_model
 
@@ -78,7 +77,7 @@ def vgg_imagenet(input_shape=(224, 224, 3),
             the scale factor is an integer used as a divider.
 
     Returns:
-        tf.keras.Model: a Keras model for VGG/ImageNet
+        keras.Model: a Keras model for VGG/ImageNet
 
     """
     # check if overrides have been provided and override
@@ -224,7 +223,7 @@ def vgg_imagenet_pretrained():
     ImageNet dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg11_imagenet_224_iq8_wq4_aq4.h5'
@@ -242,7 +241,7 @@ def vgg_melanoma_pretrained():
     SIIM-ISIC Melanoma Classification dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg11_melanoma_iq8_wq4_aq4.h5'
@@ -264,7 +263,7 @@ def vgg_odir5k_pretrained():
     pathological myopia.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg11_odir5k_iq8_wq4_aq4.h5'
@@ -282,7 +281,7 @@ def vgg_retinal_oct_pretrained():
     retinal OCT dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg11_retinal_oct_iq8_wq4_aq4.h5'
@@ -300,7 +299,7 @@ def vgg_ecg_pretrained():
     classification Physionet2017 dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg11_ecg_iq8_wq4_aq4.h5'
