@@ -18,10 +18,9 @@
 GXNOR model definition for MNIST classification.
 """
 
-from tensorflow.keras import Model
-from tensorflow.keras.layers import Input, Flatten
-from tensorflow.keras.layers.experimental.preprocessing import Rescaling
-from tensorflow.keras.utils import get_file
+from keras import Model
+from keras.layers import Input, Flatten, Rescaling
+from keras.utils.data_utils import get_file
 
 from cnn2snn import quantize, load_quantized_model
 
@@ -58,7 +57,7 @@ def gxnor_mnist(weight_quantization=0,
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
 
     Returns:
-        tf.keras.Model: a Keras model for GXNOR/MNIST
+        keras.Model: a Keras model for GXNOR/MNIST
     """
 
     # check if overrides have been provided and override
@@ -129,7 +128,7 @@ def gxnor_mnist_pretrained():
     of 5e-5.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'gxnor_mnist_iq2_wq2_aq1.h5'
