@@ -19,10 +19,10 @@ ModelNet40 model training script.
 """
 
 import argparse
+import keras
 import numpy as np
-import tensorflow as tf
 
-from tensorflow.keras.callbacks import LearningRateScheduler
+from keras.callbacks import LearningRateScheduler
 
 from cnn2snn import load_quantized_model, convert
 
@@ -65,7 +65,7 @@ def train_model(model, train_dataset, test_dataset, epochs):
     """ Trains the model.
 
     Args:
-        model (tf.keras.Model): the model to train.
+        model (keras.Model): the model to train.
         train_dataset (tf.dataset): train data.
         test_dataset (tf.dataset): test data.
         epochs (int): the number of epochs.
@@ -89,12 +89,12 @@ def evaluate_model(model, test_dataset):
     """ Evaluates model performances.
 
     Args:
-        model (tf.keras.Model or akida.Model): the model to evaluate.
+        model (keras.Model or akida.Model): the model to evaluate.
         test_dataset (tf.dataset): evaluation dataset.
     """
     labels = np.concatenate([labels for x, labels in test_dataset], axis=0)
 
-    if isinstance(model, tf.keras.Model):
+    if isinstance(model, keras.Model):
         preds = np.squeeze(np.argmax(model.predict(test_dataset), axis=1))
     else:
         pots_akida = np.empty(shape=[0, model.output_shape[-1]],
