@@ -22,6 +22,9 @@ import glob
 import numpy as np
 import tensorflow as tf
 import trimesh
+
+from keras.utils.data_utils import get_file
+
 from .pointnet_utils import pointnet_preproc
 
 
@@ -143,7 +146,7 @@ def get_modelnet_from_file(num_points, filename="ModelNet40.zip"):
             # For ModelNet40, 2 Gb to download, and 12K files to unzip,
             # so can take some time
             print("Checking for downloaded, unzipped data (one-time task)...")
-            data_dir = tf.keras.utils.get_file(
+            data_dir = get_file(
                 filename,
                 original_url,
                 extract=True,
