@@ -20,10 +20,10 @@ Common utility methods used by the training scripts.
 
 import argparse
 import numpy as np
-import tensorflow as tf
 
-from tensorflow.keras.optimizers import Adam
-from tensorflow.keras.layers import Activation
+from keras.preprocessing.image import DirectoryIterator
+from keras.optimizer_v2.adam import Adam
+from keras.layers import Activation
 
 
 def compile_model(model,
@@ -33,7 +33,7 @@ def compile_model(model,
     """ Compiles the model using Adam optimizer.
 
     Args:
-        model (tf.keras.Model): the model to compile
+        model (keras.Model): the model to compile
         learning_rate (float, optional): the learning rate. Defaults to 1e-3.
         loss (str or function, optional): the loss function. Defaults to
             'categorical_crossentropy'.
@@ -52,7 +52,7 @@ def freeze_model_before(model, freeze_before):
     """ Freezes the model before the given layer name.
 
     Args:
-        model (tf.keras.Model): the model to freeze
+        model (keras.Model): the model to freeze
         freeze_before (str): name of the layer from which the model will not be
             frozen
 
@@ -78,7 +78,7 @@ def evaluate_model(model,
     """ Evaluates model performances.
 
     Args:
-        model (tf.keras.Model): the model to evaluate
+        model (keras.Model): the model to evaluate
         x (tf.Dataset, np.array or generator): evaluation input data
         y (tf.Dataset, np.array or generator, optional): evaluation target
             data. Defaults to None.
@@ -120,7 +120,7 @@ def evaluate_akida_model(model, x, activation):
     # Datasets created as ImageDataGenerator will be looped over indefinitely,
     # they thus need a special treatment
     steps = None
-    if isinstance(x, tf.keras.preprocessing.image.DirectoryIterator):
+    if isinstance(x, DirectoryIterator):
         steps = np.math.ceil(x.samples / x.batch_size)
 
     for batch, label_batch in x:
