@@ -19,7 +19,7 @@ Training script for UTKFace model.
 """
 import numpy as np
 
-from tensorflow.keras.callbacks import LearningRateScheduler
+from keras.callbacks import LearningRateScheduler
 
 from cnn2snn import load_quantized_model, convert
 
@@ -44,7 +44,7 @@ def train_model(model, x_train, y_train, x_test, y_test, epochs, batch_size):
     """ Trains the model.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         x_test (numpy.ndarray): test data
